@@ -1,5 +1,6 @@
 import time
 import webbrowser
+from dataclasses import dataclass
 from json import dump, load
 from pathlib import Path
 from typing import Any, Dict, Optional
@@ -15,7 +16,22 @@ from . import Auth, Token, TokenProvider
 
 logger = make_logger(__name__)
 
-CLI_CLIENT_ID = "bleED0RUwb7CJ9j7D48tqSiSZRZn29AV"
+
+@dataclass
+class Env:
+    cli_client_id: str
+    auth0_tenant_base_url: str
+
+
+environments = {
+    "staging": Env(
+        cli_client_id="yJw7FCGBKg7nTT4CJ4n05QaVzhTIgtAf",
+        auth0_tenant_base_url="contxt-staging.us.auth0.com",
+    ),
+    "production": Env(
+        cli_client_id="bleED0RUwb7CJ9j7D48tqSiSZRZn29AV", auth0_tenant_base_url="ndustrial.auth0.com"
+    ),
+}
 
 
 class DeviceAuthPendingException(Exception):
@@ -31,14 +47,15 @@ class DeviceAuthDenied(Exception):
 
 
 class Auth0DeviceProvider(Api):
-    def __init__(self, auth0_tenant):
-        self.base_url = auth0_tenant
-        self.auth_service = AuthService()
+    def __init__(self, env: str = "production"):
+        self.env = env
+        self.base_url = environments[env].auth0_tenant_base_url
+        self.auth_service = AuthService(env=env)
         super().__init__(base_url=f"https://{self.base_url}")
 
     def get_device_code_url(self):
         data = {
-            "client_id": CLI_CLIENT_ID,
+            "client_id": environments[self.env].cli_client_id,
             "scope": "offline_access",
             "audience": self.auth_service.client_id,
         }
@@ -50,7 +67,7 @@ class Auth0DeviceProvider(Api):
         data = {
             "grant_type": "urn:ietf:params:oauth:grant-type:device_code",
             "device_code": code_info["device_code"],
-            "client_id": CLI_CLIENT_ID,
+            "client_id": environments[self.env].cli_client_id,
         }
 
         while True:
@@ -90,14 +107,20 @@ class UserIdentityProvider(TokenProvider):
     """
 
     def __init__(
-        self, client_id: str, client_secret: str, audience: str, cache_file: Optional[Path] = None
+        self,
+        client_id: str,
+        client_secret: str,
+        audience: str,
+        env: str = "production",
+        cache_file: Optional[Path] = None,
     ) -> None:
         super().__init__(audience)
+        self.env = env
         self.client_id = client_id
         self.client_secret = client_secret
-        self.auth_service = GetToken("ndustrial.auth0.com")
+        self.auth_service = GetToken(environments[env].auth0_tenant_base_url)
         self._refresh_token: Optional[Token] = None
-        self.device_provider = Auth0DeviceProvider("ndustrial.auth0.com")
+        self.device_provider = Auth0DeviceProvider(env)
 
         # Initialize cache
         self._cache_file = cache_file
@@ -207,10 +230,12 @@ class UserTokenProvider(TokenProvider):
     identity provider.
     """
 
-    def __init__(self, identity_provider: UserIdentityProvider, audience: str) -> None:
+    def __init__(
+        self, identity_provider: UserIdentityProvider, audience: str, env: str = "production"
+    ) -> None:
         super().__init__(audience)
         self.identity_provider = identity_provider
-        self.auth_service = AuthService()
+        self.auth_service = AuthService(env)
 
     @TokenProvider.access_token.getter  # type: ignore
     def access_token(self) -> Token:
@@ -240,10 +265,12 @@ class CliAuth(Auth):
        for the target service, authenticating with the above Auth0 access token
     """
 
-    def __init__(self) -> None:
-        super().__init__(client_id=CLI_CLIENT_ID, client_secret="")
-        self.auth_service = AuthService()
+    def __init__(self, env: str = "production") -> None:
+        super().__init__(client_id=environments[env].cli_client_id, client_secret="")
+        self.env = env
+        self.auth_service = AuthService(env)
         self.identity_provider = UserIdentityProvider(
+            env=env,
             client_id=self.client_id,
             client_secret=self.client_secret,
             audience=self.auth_service.client_id,
@@ -252,7 +279,9 @@ class CliAuth(Auth):
 
     def get_token_provider(self, audience: str) -> UserTokenProvider:
         """Get `TokenProvider` for audience `audience`"""
-        return UserTokenProvider(self.identity_provider, audience)
+        return UserTokenProvider(
+            identity_provider=self.identity_provider, audience=audience, env=self.env
+        )
 
     @property
     def user_id(self) -> str:
